@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Combinatorial algorithms to generate rhythms
 
-our $VERSION = '0.0402';
+our $VERSION = '0.0403';
 
 use Moo;
 use strictures 2;
@@ -529,7 +529,7 @@ Music::CreatingRhythms - Combinatorial algorithms to generate rhythms
 
 =head1 VERSION
 
-version 0.0402
+version 0.0403
 
 =head1 SYNOPSIS
 
@@ -542,7 +542,7 @@ version 0.0402
 C<Music::CreatingRhythms> provides the combinatorial algorithms
 described in the book, "Creating Rhythms", by Hollos. These algorithms
 are ported directly from the C, and are pretty fast. Please see the
-link below for more information.
+links below for more information.
 
 NB: Arguments are sometimes switched between book and software.
 
@@ -883,7 +883,9 @@ Examples:
 
 =head1 SEE ALSO
 
-L<https://abrazol.com/books/rhythm1/> "Creating Rhythms"
+L<https://abrazol.com/books/rhythm1/> "Creating Rhythms", the book.
+
+L<https://ology.github.io/2023/03/02/creating-rhythms-with-perl/>, my write-up.
 
 The F<t/01-methods.t> and F<eg/*> programs included with this distribution.
 
